@@ -980,7 +980,7 @@ QVariant KExiv2::getXmpTagVariant(const char* xmpTagName, bool rationalAsListOfI
                         double den = (*it).toRational().second;
 
                         if (den == 0.0)
-                            return QVariant(QVariant::Double);
+                            return QVariant(QMetaType(QMetaType::Double));
 
                         return QVariant(num / den);
                     }
